@@ -1,3 +1,4 @@
+import uuid
 import pandas as pd
 from google.ads.googleads.client import GoogleAdsClient
 from google.ads.googleads.errors import GoogleAdsException
@@ -6,10 +7,7 @@ from autoads.gads import create_adgroup,create_campaign,create_keyword,_handle_g
 df_path = 'data/keywords_to_upload.csv' # specify keywords to uplod csv here
 save_path = 'data'
 path = '/home/maunish/Upwork Projects/Google-Ads-Project/examples/google-ads.yaml'
-customer_id = '6554081276'
-threshold = 0.9
-allowed_funnels = ['LF','MF'] # available options LF, MF, UF
-allowed_status = ['PAUSED','REMOVED','UNKNOWN','UNSPECIFIED'] # options ENABLED','PAUSED','REMOVED','UNKNOWN','UNSPECIFIED'
+customer_id = '8306215642'
 
 googleads_client = GoogleAdsClient.load_from_storage(path=path, version="v9")
 
@@ -25,7 +23,7 @@ try:
     seed_keywords = df.groupby(['Keywords2']).groups  
     for k, d in seed_keywords.items():
         campaign = create_campaign(googleads_client,customer_id,campaignName=k,
-                                    budgetName=k+'_budget_', budgetDollars=1000000)
+                                    budgetName=k+'_budget_'+f"{uuid.uuid4()}", budgetDollars=100)
         campaign_id = campaign.split('/')[-1]
         data = df.iloc[d]['Keywords'].tolist()
         for keyword in data:
